==> cuteradio_0.2.0.tar.gz: cuteradio-0.2.0/src/maemo5/addpodcastdialog.cpp <==
/*
 * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 3, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include <QLineEdit>
#include <QLabel>
#include <QDialogButtonBox>
#include <QGridLayout>
#include <QMaemo5InformationBox>
#include "addpodcastdialog.h"
#include "scrollarea.h"
#include "../base/station.h"
#include "../base/podcast.h"
#include "../base/podcasts.h"
#include "../base/database.h"
#include "../base/logodownloader.h"
#include "../base/utils.h"

AddPodcastDialog::AddPodcastDialog(QWidget *parent) :
    AbstractDialog(parent),
    m_podcast(0),
    m_sourceEdit(new QLineEdit(this)),
    m_scrollArea(new ScrollArea(this)),
    m_buttonBox(new QDialogButtonBox(QDialogButtonBox::Ok, Qt::Vertical, this)),
    m_grid(new QGridLayout(this))
{
    this->setWindowTitle(tr("Add podcast"));

    QWidget *scrollWidget = new QWidget(m_scrollArea);
    QVBoxLayout *vbox = new QVBoxLayout(scrollWidget);
    vbox->setContentsMargins(0, 0, 0, 0);
    vbox->addWidget(new QLabel(tr("Source"), this));
    vbox->addWidget(m_sourceEdit);

    m_scrollArea->setWidgetResizable(true);
    m_scrollArea->setWidget(scrollWidget);
    m_scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    m_scrollArea->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);

    m_buttonBox->setEnabled(false);

    this->connect(m_sourceEdit, SIGNAL(textChanged(QString)), this, SLOT(onSourceChanged(QString)));
    this->connect(m_buttonBox, SIGNAL(accepted()), this, SLOT(addPodcast()));

    this->onOrientationChanged();
}

void AddPodcastDialog::setLandscapeLayout() {
    this->setFixedHeight(150);
    m_buttonBox->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Preferred);

    if (m_grid->isEmpty()) {
        m_grid->addWidget(m_scrollArea, 0, 0);
        m_grid->addWidget(m_buttonBox, 0, 1, Qt::AlignBottom);
    }
    else {
        m_grid->removeWidget(m_buttonBox);
        m_grid->addWidget(m_buttonBox, 0, 1, Qt::AlignBottom);
    }
}

void AddPodcastDialog::setPortraitLayout() {
    this->setFixedHeight(220);
    m_buttonBox->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);

    if (m_grid->isEmpty()) {
        m_grid->addWidget(m_scrollArea, 0, 0);
        m_grid->addWidget(m_buttonBox, 1, 0);
    }
    else {
        m_grid->removeWidget(m_buttonBox);
        m_grid->addWidget(m_buttonBox, 1, 0);
    }
}

void AddPodcastDialog::onSourceChanged(const QString &source) {
    m_buttonBox->setEnabled(!source.isEmpty());
}

void AddPodcastDialog::addPodcast() {
    this->toggleBusy(true);

    Podcast *podcast = Podcasts::getPodcast(QUrl(m_sourceEdit->text()));
    podcast->setParent(this);
    this->connect(podcast, SIGNAL(finished(Podcast*)), this, SLOT(onPodcastFinished(Podcast*)));
}

void AddPodcastDialog::onPodcastFinished(Podcast *podcast) {
    m_podcast = podcast->result();

    if (m_podcast) {
        m_podcast->setParent(this);

        LogoDownloader *downloader = new LogoDownloader(m_podcast->logo(), QString("%1%2.%3").arg(Utils::logoPath()).arg(m_podcast->id()).arg(m_podcast->logo().toString().section('.', -1)), this);
        this->connect(downloader, SIGNAL(finished(LogoDownloader*)), this, SLOT(onLogoDownloaderFinished(LogoDownloader*)));
        downloader->start();
    }
    else {
        this->toggleBusy(false);

        switch (podcast->error()) {
        case QNetworkReply::NoError:
            QMaemo5InformationBox::information(0, tr("No podcast information found"));
            break;
        default:
            QMaemo5InformationBox::information(0, podcast->errorString());
            break;
        }
    }

    podcast->deleteLater();
}

void AddPodcastDialog::onLogoDownloaderFinished(LogoDownloader *downloader) {
    if (m_podcast) {
        Database::asyncAddPodcast(m_podcast->title(),
                                  m_podcast->description(),
                                  QUrl(downloader->localPath()),
                                  m_sourceEdit->text());
    }

    this->toggleBusy(false);
    this->accept();
}

==> cuteradio_0.2.1.tar.gz: cuteradio-0.2.1/src/maemo5/addpodcastdialog.cpp <==
/*
 * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 3, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include <QLineEdit>
#include <QLabel>
#include <QRegExpValidator>
#include <QDialogButtonBox>
#include <QGridLayout>
#include <QMaemo5InformationBox>
#include "addpodcastdialog.h"
#include "scrollarea.h"
#include "../base/station.h"
#include "../base/podcast.h"
#include "../base/podcasts.h"
#include "../base/database.h"
#include "../base/logodownloader.h"
#include "../base/utils.h"

AddPodcastDialog::AddPodcastDialog(QWidget *parent) :
    AbstractDialog(parent),
    m_podcast(0),
    m_sourceEdit(new QLineEdit(this)),
    m_scrollArea(new ScrollArea(this)),
    m_buttonBox(new QDialogButtonBox(QDialogButtonBox::Ok, Qt::Vertical, this)),
    m_grid(new QGridLayout(this))
{
    this->setWindowTitle(tr("Add podcast"));

    QWidget *scrollWidget = new QWidget(m_scrollArea);
    QVBoxLayout *vbox = new QVBoxLayout(scrollWidget);
    vbox->setContentsMargins(0, 0, 0, 0);
    vbox->addWidget(new QLabel(tr("Source"), this));
    vbox->addWidget(m_sourceEdit);

    m_sourceEdit->setValidator(new QRegExpValidator(QRegExp("^http(s|)://\\S+"), m_sourceEdit));

    m_scrollArea->setWidgetResizable(true);
    m_scrollArea->setWidget(scrollWidget);
    m_scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    m_scrollArea->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);

    this->connect(m_sourceEdit, SIGNAL(textChanged(QString)), this, SLOT(onSourceChanged()));
    this->connect(m_buttonBox, SIGNAL(accepted()), this, SLOT(addPodcast()));

    this->onOrientationChanged();
    this->onSourceChanged();
}

void AddPodcastDialog::setLandscapeLayout() {
    this->setFixedHeight(150);
    m_buttonBox->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Preferred);

    if (m_grid->isEmpty()) {
        m_grid->addWidget(m_scrollArea, 0, 0);
        m_grid->addWidget(m_buttonBox, 0, 1, Qt::AlignBottom);
    }
    else {
        m_grid->removeWidget(m_buttonBox);
        m_grid->addWidget(m_buttonBox, 0, 1, Qt::AlignBottom);
    }
}

void AddPodcastDialog::setPortraitLayout() {
    this->setFixedHeight(220);
    m_buttonBox->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);

    if (m_grid->isEmpty()) {
        m_grid->addWidget(m_scrollArea, 0, 0);
        m_grid->addWidget(m_buttonBox, 1, 0);
    }
    else {
        m_grid->removeWidget(m_buttonBox);
        m_grid->addWidget(m_buttonBox, 1, 0);
    }
}

void AddPodcastDialog::toggleBusy(bool busy) {
    AbstractDialog::toggleBusy(busy);
    m_scrollArea->setEnabled(!busy);
    m_buttonBox->setEnabled(!busy);
}

void AddPodcastDialog::onSourceChanged() {
    m_buttonBox->setEnabled(m_sourceEdit->hasAcceptableInput());
}

void AddPodcastDialog::addPodcast() {
    this->toggleBusy(true);

    Podcast *podcast = Podcasts::getPodcast(QUrl(m_sourceEdit->text()));
    podcast->setParent(this);
    this->connect(podcast, SIGNAL(finished(Podcast*)), this, SLOT(onPodcastFinished(Podcast*)));
}

void AddPodcastDialog::onPodcastFinished(Podcast *podcast) {
    m_podcast = podcast->result();

    if (m_podcast) {
        m_podcast->setParent(this);

        LogoDownloader *downloader = new LogoDownloader(m_podcast->logo(), QString("%1%2.%3").arg(Utils::logoPath()).arg(m_podcast->id()).arg(m_podcast->logo().toString().section('.', -1)), this);
        this->connect(downloader, SIGNAL(finished(LogoDownloader*)), this, SLOT(onLogoDownloaderFinished(LogoDownloader*)));
        downloader->start();
    }
    else {
        this->toggleBusy(false);

        switch (podcast->error()) {
        case QNetworkReply::NoError:
            QMaemo5InformationBox::information(0, tr("No podcast information found"));
            break;
        default:
            QMaemo5InformationBox::information(0, podcast->errorString());
            break;
        }
    }

    podcast->deleteLater();
}

void AddPodcastDialog::onLogoDownloaderFinished(LogoDownloader *downloader) {
    if (m_podcast) {
        Database::asyncAddPodcast(m_podcast->title(),
                                  m_podcast->description(),
                                  QUrl(downloader->localPath()),
                                  m_sourceEdit->text());
    }

    this->toggleBusy(false);
    this->accept();
}
